import { useContext, useState } from "react";
import {
  StyleSheet,
  Text,
  TouchableOpacity,
  View,
  TouchableHighlight,
} from "react-native";
import Animated, {
  useAnimatedStyle,
  useSharedValue,
} from "react-native-reanimated";
import ColorPicker, {
  Swatches,
  InputWidget,
  HueCircular,
  Panel1,
  Panel3,
  BrightnessSlider,
  OpacitySlider,
  HueSlider,
  SaturationSlider,
} from "reanimated-color-picker";
import { AppContext, AppStyles, IsPlatformIos } from "../../utils";
import Card from "../../Components/Card";
import MySwitch from "../../Components/Switch";
import MyIcon from "../../Components/Icon";
import { useTranslation } from "react-i18next";
import MySlider from "../../Components/Slider";
import MyPickerModal from "../../Components/Modal";

const colorModePickerOptions = [
  { label: "Pulse", value: "pulse" },
  { label: "Random", value: "random" },
  { label: "Rainbow", value: "rainbow" },
];

function ColorLayer({ layerNumber, sharedColor, selected, onPress }) {
  const backgroundColorStyle = useAnimatedStyle(() => {
    return {
      backgroundColor: sharedColor.value,
    };
  });

  const contrastColorText = useAnimatedStyle(() => {
    const getContrastRatio = (hexColor) => {
      const hex = hexColor.replace("#", "");
      const r = parseInt(hex.substr(0, 2), 16);
      const g = parseInt(hex.substr(2, 2), 16);
      const b = parseInt(hex.substr(4, 2), 16);
      const luminance = (r * 0.299 + g * 0.587 + b * 0.114) / 255;
      return luminance > 0.5 ? "#000000" : "#ffffff";
    };

    let obj = {};

    obj.color = getContrastRatio(sharedColor.value);

    return obj;
  });

  const contrastColorBorder = useAnimatedStyle(() => {
    const getContrastRatio = (hexColor) => {
      const hex = hexColor.replace("#", "");
      const r = parseInt(hex.substr(0, 2), 16);
      const g = parseInt(hex.substr(2, 2), 16);
      const b = parseInt(hex.substr(4, 2), 16);
      const luminance = (r * 0.299 + g * 0.587 + b * 0.114) / 255;
      return luminance > 0.5 ? "#000000" : "#ffffff";
    };

    let obj = {};

    //obj.color = getContrastRatio(sharedColor.value);

    if (selected === true) {
      obj.borderColor = getContrastRatio(sharedColor.value);
      obj.borderBottomWidth = 2;
    } else {
      obj.borderBottomWidth = 0;
    }

    return obj;
  });

  return (
    <TouchableHighlight
      style={[
        {
          width: 30,
          height: 30,
          borderRadius: 10,
          marginRight: 10,
          elevation: 3,
        },
      ]}
      onPress={onPress}
      rippleColor="rgba(0, 0, 0, .32)"
    >
      <Animated.View
        style={[
          {
            width: "100%",
            height: "100%",
            justifyContent: "center",
            alignItems: "center",
            borderRadius: 10,
          },
          backgroundColorStyle,
        ]}
      >
        <Animated.View style={contrastColorBorder}>
          <Animated.Text
            style={[
              {
                fontSize: 16,
                fontWeight: "bold",
              },
              contrastColorText,
            ]}
          >
            {layerNumber}
          </Animated.Text>
        </Animated.View>
      </Animated.View>
    </TouchableHighlight>
  );
}

export default function LightView() {
  const appContext = useContext(AppContext);
  const { t } = useTranslation();
  const [switchState, setSwitchState] = useState(false);
  const [selectedGlasLayer, setSelectedGlasLayer] = useState(1);
  const [colorSwatchesFavorites, setColorSwatchesFavorites] = useState([]);
  const [modalDeviceColorModeVisible, setModalDeviceColorModeVisible] =
    useState(false);
  const [selectedDeviceColorMode, setSelectedDeviceColorMode] = useState("");

  const selectedColorPickerColor = useSharedValue("#ddd");
  const selectedColorLayer1 = useSharedValue(selectedColorPickerColor.value);
  const selectedColorLayer2 = useSharedValue(selectedColorPickerColor.value);
  const selectedColorLayer3 = useSharedValue(selectedColorPickerColor.value);
  const selectedColorLayer4 = useSharedValue(selectedColorPickerColor.value);

  const [sliderBrightness, setSliderBrightness] = useState(10);

  const onColorSelect = (color) => {
    selectedColorPickerColor.value = color.hex;

    switch (selectedGlasLayer) {
      case 1:
        selectedColorLayer1.value = color.hex;
        break;
      case 2:
        selectedColorLayer2.value = color.hex;
        break;
      case 3:
        selectedColorLayer3.value = color.hex;
        break;
      case 4:
        selectedColorLayer4.value = color.hex;
        break;
    }
  };

  return (
    <>
      <Card>
        <TouchableOpacity onPress={() => setModalDeviceColorModeVisible(true)}>
          <View
            style={[
              {
                flexDirection: "row",
                alignItems: "center",
                justifyContent: "space-between",
              },
              IsPlatformIos() && { marginBottom: 10 },
            ]}
          >
            <View>
              <Text style={{ color: appContext.appTheme.text }}>
                {t("screens.device.light.pickerColorModeText")}
              </Text>
              <Text style={{ color: appContext.appTheme.colors.primary }}>
                {selectedDeviceColorMode === ""
                  ? t("screens.device.light.pickerColorModePlaceholder")
                  : colorModePickerOptions.find(
                      (item) => item.value === selectedDeviceColorMode
                    ).label}
              </Text>
            </View>
            <MyIcon
              name="chevron-down"
              size={24}
              color={appContext.appTheme.icon}
            />
          </View>
        </TouchableOpacity>

        <MyPickerModal
          searchFilter
          isOpen={modalDeviceColorModeVisible}
          setIsOpen={setModalDeviceColorModeVisible}
          items={colorModePickerOptions.map((item) => {
            return {
              label: item.label,
              onPress: () => setSelectedDeviceColorMode(item.value),
              selected: selectedDeviceColorMode === item.value,
            };
          })}
        />

        <View
          style={[
            { flexDirection: "row", alignItems: "center" },
            IsPlatformIos() && { gap: 10 },
          ]}
        >
          <MySwitch
            value={switchState}
            onValueChange={(e) => setSwitchState(e)}
          />
          <MyIcon
            name={
              sliderBrightness < 1
                ? "brightness-5"
                : sliderBrightness < 40
                ? "brightness-4"
                : sliderBrightness < 80
                ? "brightness-6"
                : "brightness-7"
            }
            color={appContext.appTheme.icon}
            size={20}
          />
          <MySlider
            style={{ flex: 1 }}
            minimumValue={0}
            maximumValue={100}
            value={sliderBrightness}
            onValueChange={(v) => setSliderBrightness(v)}
          />
        </View>

        <Animated.View>
          <ColorPicker
            value={selectedColorPickerColor.value}
            thumbSize={26}
            onChange={onColorSelect}
          >
            <View
              style={{
                justifyContent: "center",
                flexDirection: "row",
                alignItems: "center",
                marginBottom: 10,
              }}
            >
              <ColorLayer
                layerNumber={1}
                sharedColor={selectedColorLayer1}
                selected={selectedGlasLayer === 1}
                onPress={() => {
                  setSelectedGlasLayer(1);
                  selectedColorPickerColor.value = selectedColorLayer1.value;
                }}
              />
              <ColorLayer
                layerNumber={2}
                sharedColor={selectedColorLayer2}
                selected={selectedGlasLayer === 2}
                onPress={() => {
                  setSelectedGlasLayer(2);
                  selectedColorPickerColor.value = selectedColorLayer2.value;
                }}
              />
              <ColorLayer
                layerNumber={3}
                sharedColor={selectedColorLayer3}
                selected={selectedGlasLayer === 3}
                onPress={() => {
                  setSelectedGlasLayer(3);
                  selectedColorPickerColor.value = selectedColorLayer3.value;
                }}
              />
              <ColorLayer
                layerNumber={4}
                sharedColor={selectedColorLayer4}
                selected={selectedGlasLayer === 4}
                onPress={() => {
                  setSelectedGlasLayer(4);
                  selectedColorPickerColor.value = selectedColorLayer4.value;
                }}
              />
            </View>

            <TouchableOpacity
              onPress={() =>
                setColorSwatchesFavorites([
                  ...colorSwatchesFavorites,
                  selectedColorPickerColor.value,
                ])
              }
              style={{
                position: "absolute",
                top: 20,
                right: 0,
              }}
            >
              <MyIcon
                name="star-outline"
                color={appContext.appTheme.icon}
                size={20}
              />
            </TouchableOpacity>

            <View
              style={{ flexDirection: "row", justifyContent: "space-evenly" }}
            >
              <Panel3 style={{ width: 200 }} />

              <BrightnessSlider style={styles.sliderStyle} vertical reverse />

              <OpacitySlider style={styles.sliderStyle} vertical reverse />
            </View>

            <Swatches
              style={styles.swatchesContainer}
              swatchStyle={styles.swatchStyle}
              colors={colorSwatchesFavorites}
            />

            {appContext.isUserExpertModeEnabled && (
              <View style={styles.previewTxtContainer}>
                <InputWidget
                  inputStyle={{
                    color: appContext.appTheme.text,
                    paddingVertical: 2,
                    borderColor: "#707070",
                    fontSize: 12,
                    marginLeft: 5,
                  }}
                  iconColor="#707070"
                />
              </View>
            )}
          </ColorPicker>
        </Animated.View>
      </Card>

      <Card>
        <View
          style={{
            flexDirection: "row",
            alignItems: "center",
            justifyContent: "space-between",
          }}
        >
          <View style={{ flexDirection: "row", alignItems: "center" }}>
            <MyIcon
              name="brightness-6"
              size={24}
              color={appContext.appTheme.icon}
            />
            <Text style={{ color: appContext.appTheme.text, marginLeft: 10 }}>
              Auto brightness
            </Text>
          </View>

          <MySwitch
            value={switchState}
            onValueChange={(e) => setSwitchState(e)}
          />
        </View>
      </Card>
    </>
  );
}

const styles = StyleSheet.create({
  previewTxtContainer: {
    paddingTop: 20,
    marginTop: 20,
    borderTopWidth: 1,
    borderColor: "#bebdbe",
  },
  panelStyle: {
    width: "60%",
    height: "60%",
    alignSelf: "center",
    borderRadius: 16,
  },
  sliderStyle: {
    borderRadius: 20,
    marginTop: 20,
    width: 10,
  },
  swatchesContainer: {
    borderTopWidth: 1,
    borderColor: "#bebdbe",
    marginTop: 20,
    paddingTop: 20,
    justifyContent: "center",
    gap: 10,
  },
  swatchStyle: {
    borderRadius: 20,
    height: 25,
    width: 25,
    margin: 0,
    marginBottom: 0,
    marginHorizontal: 0,
    marginVertical: 0,
  },
});
